"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.FileSystem = void 0;
const base64 = require("@zodash/base64");
class FileSystem {
    constructor(ctx) {
        this.ctx = ctx;
    }
    async readFile(path, options) {
        var _a;
        const encoding = (_a = options === null || options === void 0 ? void 0 : options.encoding) !== null && _a !== void 0 ? _a : 'utf-8';
        try {
            const file = await this.ctx.repo.getFile(path);
            if (file.encoding === 'base64') {
                if (encoding === 'utf-8') {
                    return base64.decode(file === null || file === void 0 ? void 0 : file.content);
                }
                else if (encoding === 'base64') {
                    return file === null || file === void 0 ? void 0 : file.content;
                }
                else {
                    throw new Error(`unsupport encoding: ${encoding}`);
                }
            }
            throw new Error(`unkown encoding with ${file.encoding}`);
        }
        catch (error) {
            if (error.status === 404) {
                throw new Error(`File(${path}) not found`);
            }
            throw error;
        }
    }
    async writeFile(path, content, options) {
        var _a;
        const { ctx } = this;
        const encoding = (_a = options === null || options === void 0 ? void 0 : options.encoding) !== null && _a !== void 0 ? _a : 'utf-8';
        if (Buffer.isBuffer(content)) {
            content = content.toString('base64');
        }
        if (await ctx.repo.hasFile(path)) {
            return await this.ctx.repo.updateFile(path, content);
        }
        try {
            return await this.ctx.repo.createFile(path, content);
        }
        catch (error) {
            delete error.request.body;
            console.log('error:', error);
            throw error;
        }
    }
}
exports.FileSystem = FileSystem;
