import type GitHubAPI from './index';
export interface RepoOptions {
    owner?: string;
    repo?: string;
    branch?: string;
    sha?: string;
}
export interface IGetFileOptions extends RepoOptions {
}
export interface ICreateFileOptions extends RepoOptions {
    message?: string;
}
export interface IUpdateFileOptions extends RepoOptions {
    message?: string;
}
export interface IDeleteFileOptions extends RepoOptions {
    message?: string;
}
export interface IListFilesOptions extends RepoOptions {
}
export interface GitHubRepoFile {
    type: 'file';
    encoding: 'base64';
    size: number;
    name: string;
    path: string;
    content: string;
    sha: string;
    url: string;
    git_url: string;
    download_url: string;
}
export declare class Repo {
    private readonly ctx;
    constructor(ctx: GitHubAPI);
    private getOwner;
    private getRepo;
    private getBranch;
    private getPath;
    private getMessage;
    private getContent;
    private getSha;
    hasFile(path: string, options?: IGetFileOptions): Promise<boolean>;
    getFile(path: string, options?: IGetFileOptions): Promise<GitHubRepoFile>;
    createFile(path: string, content: string, options?: ICreateFileOptions): Promise<import("@octokit/types").OctokitResponse<{
        content: {
            name?: string;
            path?: string;
            sha?: string;
            size?: number;
            url?: string;
            html_url?: string;
            git_url?: string;
            download_url?: string;
            type?: string;
            _links?: {
                self?: string;
                git?: string;
                html?: string;
            };
        };
        commit: {
            sha?: string;
            node_id?: string;
            url?: string;
            html_url?: string;
            author?: {
                date?: string;
                name?: string;
                email?: string;
            };
            committer?: {
                date?: string;
                name?: string;
                email?: string;
            };
            message?: string;
            tree?: {
                url?: string;
                sha?: string;
            };
            parents?: {
                url?: string;
                html_url?: string;
                sha?: string;
            }[];
            verification?: {
                verified?: boolean;
                reason?: string;
                signature?: string;
                payload?: string;
            };
        };
    }, 200> | import("@octokit/types").OctokitResponse<{
        content: {
            name?: string;
            path?: string;
            sha?: string;
            size?: number;
            url?: string;
            html_url?: string;
            git_url?: string;
            download_url?: string;
            type?: string;
            _links?: {
                self?: string;
                git?: string;
                html?: string;
            };
        };
        commit: {
            sha?: string;
            node_id?: string;
            url?: string;
            html_url?: string;
            author?: {
                date?: string;
                name?: string;
                email?: string;
            };
            committer?: {
                date?: string;
                name?: string;
                email?: string;
            };
            message?: string;
            tree?: {
                url?: string;
                sha?: string;
            };
            parents?: {
                url?: string;
                html_url?: string;
                sha?: string;
            }[];
            verification?: {
                verified?: boolean;
                reason?: string;
                signature?: string;
                payload?: string;
            };
        };
    }, 201>>;
    updateFile(path: string, content: string, options?: IUpdateFileOptions): Promise<import("@octokit/types").OctokitResponse<{
        content: {
            name?: string;
            path?: string;
            sha?: string;
            size?: number;
            url?: string;
            html_url?: string;
            git_url?: string;
            download_url?: string;
            type?: string;
            _links?: {
                self?: string;
                git?: string;
                html?: string;
            };
        };
        commit: {
            sha?: string;
            node_id?: string;
            url?: string;
            html_url?: string;
            author?: {
                date?: string;
                name?: string;
                email?: string;
            };
            committer?: {
                date?: string;
                name?: string;
                email?: string;
            };
            message?: string;
            tree?: {
                url?: string;
                sha?: string;
            };
            parents?: {
                url?: string;
                html_url?: string;
                sha?: string;
            }[];
            verification?: {
                verified?: boolean;
                reason?: string;
                signature?: string;
                payload?: string;
            };
        };
    }, 200> | import("@octokit/types").OctokitResponse<{
        content: {
            name?: string;
            path?: string;
            sha?: string;
            size?: number;
            url?: string;
            html_url?: string;
            git_url?: string;
            download_url?: string;
            type?: string;
            _links?: {
                self?: string;
                git?: string;
                html?: string;
            };
        };
        commit: {
            sha?: string;
            node_id?: string;
            url?: string;
            html_url?: string;
            author?: {
                date?: string;
                name?: string;
                email?: string;
            };
            committer?: {
                date?: string;
                name?: string;
                email?: string;
            };
            message?: string;
            tree?: {
                url?: string;
                sha?: string;
            };
            parents?: {
                url?: string;
                html_url?: string;
                sha?: string;
            }[];
            verification?: {
                verified?: boolean;
                reason?: string;
                signature?: string;
                payload?: string;
            };
        };
    }, 201>>;
    deleteFile(path: string, options?: IDeleteFileOptions): Promise<import("@octokit/types").OctokitResponse<{
        content: {
            name?: string;
            path?: string;
            sha?: string;
            size?: number;
            url?: string;
            html_url?: string;
            git_url?: string;
            download_url?: string;
            type?: string;
            _links?: {
                self?: string;
                git?: string;
                html?: string;
            };
        };
        commit: {
            sha?: string;
            node_id?: string;
            url?: string;
            html_url?: string;
            author?: {
                date?: string;
                name?: string;
                email?: string;
            };
            committer?: {
                date?: string;
                name?: string;
                email?: string;
            };
            message?: string;
            tree?: {
                url?: string;
                sha?: string;
            };
            parents?: {
                url?: string;
                html_url?: string;
                sha?: string;
            }[];
            verification?: {
                verified?: boolean;
                reason?: string;
                signature?: string;
                payload?: string;
            };
        };
    }, 200>>;
    listFiles(path?: string, options?: IListFilesOptions): Promise<{
        path: string;
        mode: string;
        type: 'tree' | 'blob';
        sha: string;
        size: number;
        url: string;
    }[]>;
}
